// Copyright 2023 Harness, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package webhook

import (
	"context"
	"fmt"

	"github.com/harness/gitness/app/auth"
	"github.com/harness/gitness/types"
	"github.com/harness/gitness/types/enum"
)

// List returns the webhooks from the provided repository.
func (c *Controller) List(
	ctx context.Context,
	session *auth.Session,
	repoRef string,
	filter *types.WebhookFilter,
) ([]*types.Webhook, int64, error) {
	repo, err := c.getRepoCheckAccess(ctx, session, repoRef, enum.PermissionRepoView)
	if err != nil {
		return nil, 0, err
	}

	count, err := c.webhookStore.Count(ctx, enum.WebhookParentRepo, repo.ID, filter)
	if err != nil {
		return nil, 0, fmt.Errorf("failed to count webhooks for repo with id %d: %w", repo.ID, err)
	}

	webhooks, err := c.webhookStore.List(ctx, enum.WebhookParentRepo, repo.ID, filter)
	if err != nil {
		return nil, 0, fmt.Errorf("failed to list webhooks for repo with id %d: %w", repo.ID, err)
	}

	return webhooks, count, nil
}
